@@ -13,4 +13,10 @@ extern reiser4_object_t *reiser4_semantic_open(reiser4_tree_t *tree,
 					       reiser4_key_t *from,
 					       bool_t follow);
 
+extern reiser4_object_t *reiser4_semantic_try_open(reiser4_tree_t *tree,
+						   char *path, 
+						   reiser4_key_t *from,
+						   bool_t follow);
+
+
 #endif
