@@ -54,8 +54,7 @@ reiser4_journal_t *reiser4_journal_open(
 	rid_t pid;
 	blk_t start;
 	count_t blocks;
-	
-	fs_desc_t desc;
+	uint32_t blksize;
 	reiser4_plug_t *plug;
 	reiser4_journal_t *journal;
 	
@@ -85,14 +84,14 @@ reiser4_journal_t *reiser4_journal_open(
 	start = reiser4_format_start(fs->format);
 	blocks = reiser4_format_get_len(fs->format);
 
-	desc.device = journal->device;
-	desc.blksize = reiser4_master_get_blksize(fs->master);
+	blksize = reiser4_master_get_blksize(fs->master);
 	
 	/* Initializing journal entity by means of calling "open" method from
 	   found journal plugin. */
 	if (!(journal->ent = plug_call(plug->o.journal_ops, open,
-				       &desc, fs->format->ent,
-				       fs->oid->ent, start, blocks))) 
+				       journal->device, blksize, 
+				       fs->format->ent, fs->oid->ent, 
+				       start, blocks))) 
 	{
 		aal_error("Can't open journal %s on %s.",
 			  plug->label, device->name);
@@ -117,21 +116,24 @@ errno_t reiser4_journal_layout(reiser4_journal_t *journal,
 			 journal->ent, region_func, data);
 }
 
-static errno_t cb_action_mark(void *entity, blk_t start,
-			      count_t width, void *data)
-{
-	return reiser4_alloc_occupy((reiser4_alloc_t *)data,
-				    start, width);
+static errno_t cb_action_mark(blk_t start, count_t width, void *data) {
+	reiser4_fs_t *fs = (reiser4_fs_t *)data;
+	errno_t res;
+
+	if ((res = reiser4_format_dec_free(fs->format, width)))
+		return res;
+		
+	return reiser4_alloc_occupy(fs->alloc, start, width);
 }
 
-/* Marks format area as used */
+/* Marks journal area as used */
 errno_t reiser4_journal_mark(reiser4_journal_t *journal) {
 	aal_assert("umka-1855", journal != NULL);
 	aal_assert("umka-1856", journal->fs != NULL);
 	aal_assert("umka-1856", journal->fs->alloc != NULL);
 	
 	return reiser4_journal_layout(journal, cb_action_mark,
-				      journal->fs->alloc);
+				      journal->fs);
 }
 
 /* Creates journal on specified jopurnal. Returns initialized instance */
@@ -142,8 +144,7 @@ reiser4_journal_t *reiser4_journal_create(
 	rid_t pid;
 	blk_t start;
 	count_t blocks;
-
-	fs_desc_t desc;
+	uint32_t blksize;
 	reiser4_plug_t *plug;
 	reiser4_journal_t *journal;
 
@@ -156,7 +157,6 @@ reiser4_journal_t *reiser4_journal_create(
 
 	journal->fs = fs;
 	journal->device = device;
-	journal->fs->journal = journal;
 
 	/* Getting journal plugin to be used. */
 	if ((pid = reiser4_format_journal_pid(fs->format)) == INVAL_PID) {
@@ -172,13 +172,13 @@ reiser4_journal_t *reiser4_journal_create(
 	start = reiser4_format_start(fs->format);
 	blocks = reiser4_format_get_len(fs->format);
 
-	desc.device = journal->device;
-	desc.blksize = reiser4_master_get_blksize(fs->master);
+	blksize = reiser4_master_get_blksize(fs->master);
 	
 	/* Creating journal entity. */
 	if (!(journal->ent = plug_call(plug->o.journal_ops, create,
-				       &desc, fs->format->ent,
-				       fs->oid->ent, start, blocks))) 
+				       journal->device, blksize, 
+				       fs->format->ent, fs->oid->ent, 
+				       start, blocks))) 
 	{
 		aal_error("Can't create journal %s on %s.",
 			  plug->label, journal->device->name);
@@ -245,7 +245,6 @@ void reiser4_journal_close(
 	aal_assert("umka-102", journal != NULL);
 	
 	reiser4_journal_sync(journal);
-	journal->fs->journal = NULL;
 	
 	plug_call(journal->ent->plug->o.journal_ops, 
 		  close, journal->ent);
