@@ -20,10 +20,8 @@ errno_t repair_fs_open(repair_data_t *repair,
 	aal_assert("vpf-159",  hdevice != NULL);
 	aal_assert("vpf-1556", jdevice != NULL);
 
-	len = aal_device_len(hdevice);
-	if (reiser4_fs_check_len(hdevice, 512, len)) {
-		fsck_mess("The given device '%s' is of %llu what is too "
-			  "small for the filesystem.", hdevice->name, len);
+	len = repair_format_len_old(hdevice, 512);
+	if (repair_format_check_len_old(hdevice, 512, len)) {
 		repair_error_count(repair, RE_FATAL);
 		return 0;
 	}
@@ -51,6 +49,12 @@ errno_t repair_fs_open(repair_data_t *repair,
 	
 	res |= repair_master_check_struct(fs, repair->mode, repair->flags);
 	
+	if (fs->format) {
+		/* Mater could be changed, reopen the format after that. */
+		reiser4_format_close(fs->format);
+		fs->format = reiser4_format_open(fs);
+	}
+	
 	if (repair_error_fatal(res)) {
 		aal_fatal("Failed to open the master super block.");
 		goto error_fs_close;
@@ -157,7 +161,7 @@ errno_t repair_fs_replay(reiser4_fs_t *fs) {
 
 /* Pack passed @fs to @stream. */
 errno_t repair_fs_pack(reiser4_fs_t *fs, 
-		       aux_bitmap_t *bitmap, 
+		       reiser4_bitmap_t *bitmap, 
 		       aal_stream_t *stream) 
 {
 	count_t len;
@@ -207,7 +211,7 @@ errno_t repair_fs_pack(reiser4_fs_t *fs,
 		errno_t res;
 		
 		/* We're not interested in unused blocks yet. */
-		if (!aux_bitmap_test(bitmap, blk))
+		if (!reiser4_bitmap_test(bitmap, blk))
 			continue;
 
 		/* We're not interested in other blocks, but tree nodes. */
@@ -246,16 +250,16 @@ errno_t repair_fs_pack(reiser4_fs_t *fs,
 }
 
 static errno_t cb_mark_used(uint64_t start, uint64_t count, void *data) {
-	aux_bitmap_t *bitmap = (aux_bitmap_t *)data;
+	reiser4_bitmap_t *bitmap = (reiser4_bitmap_t *)data;
 
-	aux_bitmap_mark_region(bitmap, start, count);
+	reiser4_bitmap_mark_region(bitmap, start, count);
 	
 	return 0;
 }
 
 /* Unpack filesystem from @stream to @device. */
 reiser4_fs_t *repair_fs_unpack(aal_device_t *device,
-			       aux_bitmap_t *bitmap,
+			       reiser4_bitmap_t *bitmap,
 			       aal_stream_t *stream)
 {
 	uint64_t bn;
@@ -381,7 +385,7 @@ reiser4_fs_t *repair_fs_unpack(aal_device_t *device,
 		goto error_free_backup;
 	}
 
-	if (repair_journal_unpack(fs, stream))
+	if (!(fs->journal = repair_journal_unpack(fs, stream)))
 		goto error_free_backup;
 	
 	/* If @bitmap is given, save there unpacked blocks of the fs. */
@@ -389,7 +393,7 @@ reiser4_fs_t *repair_fs_unpack(aal_device_t *device,
 		uint64_t len = reiser4_format_get_len(fs->format);
 		
 		/* Resize the bitmap. */
-		aux_bitmap_resize(bitmap, len);
+		reiser4_bitmap_resize(bitmap, len);
 		
 		if (reiser4_fs_layout(fs, cb_mark_used, bitmap)) {
 			aal_error("Can't to mark all frozen fs "
@@ -433,7 +437,7 @@ reiser4_fs_t *repair_fs_unpack(aal_device_t *device,
 			goto error;
 
 		if (bitmap) {
-			aux_bitmap_mark(bitmap, pack ? 
+			reiser4_bitmap_mark(bitmap, pack ? 
 					node->block->nr : block->nr);
 		}
 		
@@ -452,7 +456,7 @@ reiser4_fs_t *repair_fs_unpack(aal_device_t *device,
  error_free_journal:
 	reiser4_journal_close(fs->journal);
  error_free_backup:
-	reiser4_backup_close(fs->backup);
+	/* Backup is not openned, just raw blocks are copied. */
  error_free_status:
 	reiser4_status_close(fs->status);
  error_free_alloc:
@@ -498,8 +502,8 @@ errno_t repair_fs_check_backup(aal_device_t *device, backup_hint_t *hint) {
 		return RE_FATAL;
 
 	/* Master backup starts on 1st byte. Note: Every backuper must set 
-	   hint->el[next index] correctly. */
-	hint->el[BK_MASTER] = hint->block.data + 1;
+	   hint->off[next index] correctly. */
+	hint->off[BK_MASTER] = 1;
 
 	/* Check the master backup structure. */
 	if ((res = repair_master_check_backup(hint)))
