@@ -325,19 +325,17 @@ static bool_t repair_tree_need_conv(reiser4_tree_t *tree,
 /* Prepare repair convertion and perform it. */
 static errno_t repair_tree_conv(reiser4_tree_t *tree, 
 				reiser4_place_t *dst,
-				reiser4_place_t *src) 
+				reiser4_plug_t *plug) 
 {
 	conv_hint_t hint;
 
 	/* Set bytes, plug, offset and count in @hint */
 	aal_memset(&hint, 0, sizeof(hint));
-	hint.plug = src->plug;
+	hint.plug = plug;
 	
-	reiser4_key_assign(&hint.offset, &dst->key);
-	reiser4_key_set_offset(&hint.offset, 
-			       reiser4_key_get_offset(&src->key));
-
-	hint.count = plug_call(src->plug->o.item_ops->object, size, src);
+	aal_memcpy(&hint.offset, &dst->key, sizeof(dst->key));
+	hint.count = plug_call(dst->plug->o.item_ops->object, size, dst);
+	hint.ins_hole = 1;
 
 	return reiser4_flow_convert(tree, &hint);
 }
@@ -432,9 +430,32 @@ static errno_t cb_prep_insert_raw(reiser4_place_t *place,
 static errno_t cb_insert_raw(reiser4_node_t *node, pos_t *pos, 
 			     trans_hint_t *hint) 
 {
-	return plug_call(node->plug->o.node_ops, insert_raw, node, pos, hint);
+	return plug_call(node->plug->o.node_ops, 
+			 insert_raw, node, pos, hint);
 }
 
+#if 0
+/* Debugging. */
+uint64_t maxreal_offset(reiser4_node_t *node, uint32_t item) {
+	reiser4_place_t place;
+	reiser4_key_t key;
+	pos_t pos = {item, MAX_UINT32};
+	
+	if (!node) return MAX_UINT64;
+
+	if (reiser4_node_items(node) <= item)
+		return MAX_UINT64;
+	
+	if (reiser4_place_open(&place, node, &pos))
+		return MAX_UINT64;
+	
+	if (reiser4_item_maxreal_key(&place, &key))
+		return MAX_UINT64;
+
+	return key.body[3];
+}
+#endif
+
 /* Insert the item into the tree overwriting an existent in the tree item 
    if needed. Does not insert branches. */
 errno_t repair_tree_insert(reiser4_tree_t *tree, reiser4_place_t *src, 
@@ -471,9 +492,8 @@ errno_t repair_tree_insert(reiser4_tree_t *tree, reiser4_place_t *src,
 	hint.place_func = NULL;
 	hint.region_func = func;
 	hint.data = data;
-	hint.shift_flags = SF_DEFAULT;
 	
-	reiser4_key_assign(&hint.offset, &src->key);
+	aal_memcpy(&hint.offset, &src->key, sizeof(src->key));
 	level = reiser4_node_get_level(src->node);
 	
 	while (1) {
@@ -506,7 +526,7 @@ errno_t repair_tree_insert(reiser4_tree_t *tree, reiser4_place_t *src,
 			}
 			
 			if (conv) {
-				res = repair_tree_conv(tree, &dst, src);
+				res = repair_tree_conv(tree, &dst, src->plug);
 				if (res) return res;
 
 				/* Repeat lookup after @dst conversion. */
@@ -521,13 +541,32 @@ errno_t repair_tree_insert(reiser4_tree_t *tree, reiser4_place_t *src,
 
 		/* Insert_raw can insert the whole item (!dst.plug) or if dst &
 		   src items are of the same plugin. */
-		if ((dst.plug && plug_equal(dst.plug, src->plug)) || !dst.plug)
-		{
+		if (!dst.plug || plug_equal(dst.plug, src->plug)) {
+			hint.shift_flags = SF_DEFAULT;
+			
+			/* If we are in the middle of the unit, set HOLD_POS
+			   to not lose the unit it if some space is needed. */
+			if (dst.plug) {
+				reiser4_key_t ukey;
+
+				reiser4_item_get_key(&dst, &ukey);
+				
+				if (reiser4_key_compfull(&ukey, 
+							 &hint.offset) <= 0)
+				{
+					hint.shift_flags |= SF_HOLD_POS;
+				}
+			}
+			
 			res = reiser4_tree_modify(tree, &dst, &hint, level,
 						  cb_prep_insert_raw,
 						  cb_insert_raw);
 			
 			if (res) goto error;
+		} else if (dst.plug->id.group == TAIL_ITEM) {
+			/* Do not overwrite tail items as they do not have 
+			   holes. Only a hole can be overwritten. */
+			return 0;
 		} else {
 			/* For not equal plugins do coping. */
 			fsck_mess("Node (%llu), item (%u): the item (%s) [%s] "
@@ -550,15 +589,16 @@ errno_t repair_tree_insert(reiser4_tree_t *tree, reiser4_place_t *src,
 		lhint.key = &hint.maxkey;
 			
 		/* Lookup by end_key. */
-		res = src->plug->o.item_ops->balance->lookup(src, &lhint,
-							     FIND_EXACT);
-
-		if (res < 0) return res;
+		if ((res = plug_call(src->plug->o.item_ops->balance,
+				     lookup, src, &lhint, FIND_EXACT)) < 0)
+		{
+			return res;
+		}
 		
 		if (src->pos.unit >= scount)
 			break;
 
-		reiser4_key_assign(&hint.offset, &hint.maxkey);
+		aal_memcpy(&hint.offset, &hint.maxkey, sizeof(hint.offset));
 	}
 	
 	return 0;
