@@ -180,7 +180,7 @@ generic_entity_t *alloc40_unpack(aal_device_t *device,
 		goto error_free_alloc;
 	}
 
-	if (!(alloc->bitmap = aux_bitmap_create(blocks)))
+	if (!(alloc->bitmap = reiser4_bitmap_create(blocks)))
 		goto error_free_alloc;
 
 	/* Initializing adler checksums. */
@@ -203,14 +203,14 @@ generic_entity_t *alloc40_unpack(aal_device_t *device,
 	}
 
 	alloc->state = (1 << ENTITY_DIRTY);
-	aux_bitmap_calc_marked(alloc->bitmap);
+	reiser4_bitmap_calc_marked(alloc->bitmap);
 	
 	return (generic_entity_t *)alloc;
 
  error_free_crc:
 	aal_free(alloc->crc);
  error_free_bitmap:
-	aux_bitmap_close(alloc->bitmap);
+	reiser4_bitmap_close(alloc->bitmap);
  error_free_alloc:
 	aal_free(alloc);
 	return NULL;
@@ -290,8 +290,9 @@ void alloc40_print(generic_entity_t *entity,
 	aal_stream_format(stream, "[ ");
 
 	while (start < total) {
-		if (!(blocks = aux_bitmap_find_region(alloc->bitmap, &start,
-						      total - start, 1)))
+		blocks = reiser4_bitmap_find_region(alloc->bitmap, &start,  
+						    total - start, 1);
+		if (!blocks) 
 			break;
 
 		aal_stream_format(stream, "%llu(%llu) ", start, blocks);
@@ -303,7 +304,7 @@ void alloc40_print(generic_entity_t *entity,
 
 
 static void cb_inval_warn(blk_t start, uint32_t ladler, uint32_t cadler) {
-	fsck_mess("Checksum missmatch in bitmap block %llu. Checksum "
+	fsck_mess("Checksum mismatch in bitmap block %llu. Checksum "
 		  "is 0x%x, should be 0x%x.", start, ladler, cadler);
 }
 
@@ -328,6 +329,7 @@ errno_t alloc40_check_struct(generic_entity_t *entity, uint8_t mode) {
 	if (mode == RM_CHECK)
 		return RE_FIXABLE;
 
+	alloc->state = (1 << ENTITY_DIRTY);
 	fsck_mess("Checksums will be fixed later.");
 	return 0;
 }
