@@ -6,7 +6,7 @@
 #ifdef ENABLE_FNV1_HASH
 #include <reiser4/plugin.h>
 
-static uint64_t fnv1_hash_build(char *name, uint32_t len) {
+static uint64_t fnv1_hash_build(unsigned char *name, uint32_t len) {
 	uint32_t i;
 	uint64_t a = 0xcbf29ce484222325ull;
 	const uint64_t fnv_64_prime = 0x100000001b3ull;
@@ -25,9 +25,9 @@ static reiser4_hash_ops_t fnv1_hash_ops = {
 static reiser4_plug_t fnv1_hash_plug = {
 	.cl    = class_init,
 	.id    = {HASH_FNV1_ID, 0, HASH_PLUG_TYPE},
-#ifndef ENABLE_STAND_ALONE
+#ifndef ENABLE_MINIMAL
 	.label = "fnv1_hash",
-	.desc  = "Fnv1 hash for reiser4, ver. " VERSION,
+	.desc  = "Fnv1 hash for reiser4. ",
 #endif
 	.o = {
 		.hash_ops = &fnv1_hash_ops
