@@ -30,7 +30,7 @@ do {								               \
         h1 += b1;							       \
 } while(0)
 
-uint64_t tea_hash_build(char *name, uint32_t len) {
+uint64_t tea_hash_build(unsigned char *name, uint32_t len) {
 	uint64_t k[] = { 0x9464a485, 0x542e1a94, 0x3e846bff, 0xb75bcfc3}; 
 
 	uint64_t i;
@@ -148,9 +148,9 @@ static reiser4_hash_ops_t tea_hash_ops = {
 static reiser4_plug_t tea_hash_plug = {
 	.cl = class_init,
 	.id = {HASH_TEA_ID, 0, HASH_PLUG_TYPE},
-#ifndef ENABLE_STAND_ALONE
+#ifndef ENABLE_MINIMAL
 	.label = "tea_hash",
-	.desc  = "Tea hash for reiser4, ver. " VERSION,
+	.desc  = "Tea hash for reiser4. ",
 #endif
 	.o = {
 		.hash_ops = &tea_hash_ops
