@@ -309,6 +309,14 @@ errno_t node40_fetch(reiser4_node_t *entity,
 		return -EINVAL;
 	}
 
+	/* Init item specific stuff. */
+	if (place->plug->o.item_ops->tree->init) {
+		place->plug->o.item_ops->tree->init(place);
+	} else {
+		/* Zero all item-specific fields here. */
+		place->off = 0;
+	}
+	
 	return 0;
 }
 
@@ -837,9 +845,9 @@ errno_t node40_remove(reiser4_node_t *entity, pos_t *pos,
 
 /* Fuses two mergeable items if they lie in the same node side by side. This is
    needed for fsck if it discovered, that two items are mergeable and lie in the
-   same node (due to some corruption or fail) it will fuse them. */
-static errno_t node40_fuse(reiser4_node_t *entity,  pos_t *left_pos,
-			   pos_t *right_pos)
+   same node (due to some corruption or fail) it will merge them. */
+static errno_t node40_merge(reiser4_node_t *entity,  
+			    pos_t *left_pos, pos_t *right_pos)
 {
 	errno_t res;
 	uint32_t pol;
@@ -864,7 +872,7 @@ static errno_t node40_fuse(reiser4_node_t *entity,  pos_t *left_pos,
 	delta = left_pos->item - right_pos->item;
 	
 	if (aal_abs(delta) > 1) {
-		aal_error("Can't fuse items which lie not side "
+		aal_error("Can't merge items which lie not side "
 			  "by side each other.");
 		return -EINVAL;
 	}
@@ -884,15 +892,15 @@ static errno_t node40_fuse(reiser4_node_t *entity,  pos_t *left_pos,
 	aal_assert("umka-2686", plug_equal(left_place.plug,
 					   right_place.plug));
 
-	/* Check if item needs some special actions to fuse (like eliminate
-	   header). If so, fuse items. */
-	if (left_place.plug->o.item_ops->balance->fuse) {
+	/* Check if item needs some special actions to merge (like eliminate
+	   header). If so, merge items. */
+	if (left_place.plug->o.item_ops->balance->merge) {
 		int32_t space;
 
 		/* Returned space is released space in node and it should be
 		   counted in node header. */
 		space = plug_call(left_place.plug->o.item_ops->balance,
-				  fuse, &left_place, &right_place);
+				  merge, &left_place, &right_place);
 
 		if (space) {
 			right_pos->unit = 0;
@@ -1264,13 +1272,6 @@ static errno_t node40_unite(reiser4_node_t *src_entity,
 	   not point it, that is next insert will not be dealing with it. */
 	remove = (hint->units_bytes == src_place.len || units == 0);
 	
-	/*
-	if (hint->control & SF_UPDATE_POINT) {
-		remove = remove && (hint->result & SF_MOVE_POINT ||
-				    pos.item != hint->pos.item);
-	}
-	*/
-	
 	/* Updating item's keys after shift_unit() is finished. */
 	if (left_shift) {
 		/* We do not need to update key of the src item which is going
@@ -1461,9 +1462,9 @@ static errno_t node40_predict(reiser4_node_t *src_entity,
 }
 
 /* Moves some amount of whole items from @src_entity to @dst_entity */
-static errno_t node40_transfuse(reiser4_node_t *src_entity,
-				reiser4_node_t *dst_entity, 
-				shift_hint_t *hint)
+static errno_t node40_move(reiser4_node_t *src_entity,
+			   reiser4_node_t *dst_entity, 
+			   shift_hint_t *hint)
 {	
 	errno_t res;
 	pos_t src_pos;
@@ -1552,8 +1553,8 @@ static errno_t node40_shift(reiser4_node_t *src_entity,
 	aal_assert("umka-2050", src_entity != NULL);
 	aal_assert("umka-2051", dst_entity != NULL);
 
-	/* First pass is merge border items. Heer we check is we are allowed to
-	   merge items. */
+	/* First pass: if merge is allowed, try to merge border items; 
+	   otheriwse, check that border items are not mergeable. */
 	if (hint->control & SF_ALLOW_MERGE) {
 		if ((res = node40_unite(src_entity, dst_entity, hint, 0))) {
 			aal_error("Can't merge two nodes during "
@@ -1590,9 +1591,9 @@ static errno_t node40_shift(reiser4_node_t *src_entity,
 
 	/* Second pass is started here. Moving some amount of whole items from
 	   @src_entity to @dst_entity. */
-	if ((res = node40_transfuse(src_entity, dst_entity, hint))) {
-		aal_error("Can't transfuse two nodes during node "
-			  "shift operation.");
+	if ((res = node40_move(src_entity, dst_entity, hint))) {
+		aal_error("Can't move items from the numde %llu to %llu.",
+			  src_entity->block->nr, dst_entity->block->nr);
 		return res;
 	}
 
@@ -1607,7 +1608,7 @@ static errno_t node40_shift(reiser4_node_t *src_entity,
 	   up. */
 	if (hint->control & SF_ALLOW_MERGE) {
 		if ((res = node40_unite(src_entity, dst_entity, hint, 1))) {
-			aal_error("Can't merge two nodes during"
+			aal_error("Can't unite two nodes during"
 				  "node shift operation.");
 			return res;
 		}
@@ -1657,7 +1658,7 @@ static reiser4_node_ops_t node40_ops = {
 #ifndef ENABLE_MINIMAL
 	.init		= node40_init,
 	.sync           = node40_sync,
-	.fuse           = node40_fuse,
+	.merge          = node40_merge,
 
 	.pack           = node40_pack,
 	.unpack         = node40_unpack,
