@@ -250,6 +250,7 @@ static int reg40_conv_prepare(reg40_t *reg, conv_hint_t *hint,
 	if (plug_equal(reg->body.plug, info->opset.plug[OPSET_EXTENT])) {
 		/* Extent found, all previous items were tails, convert all 
 		   previous ones to extents. */
+		hint->plug = reg->body.plug;
 		
 		/* Convert from 0 to this item offset bytes. */
 		if (!(hint->count = plug_call(reg->body.key.plug->o.key_ops, 
@@ -449,15 +450,13 @@ errno_t reg40_check_struct(object_entity_t *object, place_func_t func,
 			if (mode == RM_BUILD) {
 				if ((result = obj40_convert(&reg->obj, &conv)))
 					return result;
-
-				/* Evth was converted, update bytes. */
-				hint.bytes += conv.bytes;
 			} else {
 				res |= RE_FATAL;
 			}
 			
+			reg->body_plug = conv.plug;
 			aal_memset(&conv.offset, 0, sizeof(conv.offset));
-			goto next;
+			continue;
 		}
 		
 		/* No more items, break out here. */
