@@ -3,10 +3,6 @@
    
    print.c -- filesystem print related code. */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h> 
-#endif
-
 #include <stdio.h>
 #include <unistd.h>
 #include <errno.h>
